pub struct ReplicaSyncStatus {
pub replica_id: String,
pub active: bool,
pub last_applied_lsn: Option<u64>,
pub remote_lsn: u64,
pub servable_lsn: Option<u64>,
pub unarchived_lsn: Option<u64>,
pub lag_lsn: Option<u64>,
pub lag_bytes: Option<u64>,
pub lag_ms: Option<u64>,
pub stale: bool,
pub repair_action: SyncRepairAction,
pub last_sync_error: Option<String>,
}Fields
replica_id: Stringactive: boollast_applied_lsn: Option<u64>remote_lsn: u64servable_lsn: Option<u64>Largest contiguous retained-unit LSN currently servable after the
replica cursor. This can lag behind remote_lsn while the primary has
progressed but its latest WAL records have not yet been published into
retained segments.
unarchived_lsn: Option<u64>Primary progress that is not yet represented in contiguous retained history for this replica.
lag_lsn: Option<u64>lag_bytes: Option<u64>Estimated retained segment bytes that overlap the unapplied LSN range.
lag_ms: Option<u64>Milliseconds since the primary-side cursor was last acknowledged while stale.
stale: boolrepair_action: SyncRepairActionlast_sync_error: Option<String>Trait Implementations
Sourceimpl Clone for ReplicaSyncStatus
impl Clone for ReplicaSyncStatus
Sourcefn clone(&self) -> ReplicaSyncStatus
fn clone(&self) -> ReplicaSyncStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicaSyncStatus
impl Debug for ReplicaSyncStatus
impl Eq for ReplicaSyncStatus
Sourceimpl PartialEq for ReplicaSyncStatus
impl PartialEq for ReplicaSyncStatus
impl StructuralPartialEq for ReplicaSyncStatus